package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import com.alibaba.fastjson.JSONObject;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service.EntityService;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.Entity;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;

@RestController
@RequestMapping(value = "")
public class EntityController {
	@Autowired
    EntityService entityservice;


	@RequestMapping(method = RequestMethod.GET, value = "/entities/{entity_id}")
    @PreAuthorize("@entity_pms.check(#entity_id,'READ')")
    public ResponseEntity<Entity> get(@PathVariable("entity_id") String entity_id) {
        Entity entity = entityservice.get( entity_id);
        return ResponseEntity.status(HttpStatus.OK).body(entity);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/entities/{entity_id}/save")
    @PreAuthorize("@entity_pms.check(#entity_id,'')")
    public ResponseEntity<Entity> save(@PathVariable("entity_id") String entity_id, @RequestBody Entity entity) {
        Entity entity2 = entityservice.save(entity_id, entity);
        return ResponseEntity.status(HttpStatus.OK).body(entity2);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/entities")
    @PreAuthorize("@entity_pms.check('CREATE')")
    public ResponseEntity<Entity> create(@RequestBody Entity entity) {
        Entity entity2 = entityservice.create(entity);
        return ResponseEntity.status(HttpStatus.OK).body(entity2);
    }

	@RequestMapping(method = RequestMethod.DELETE, value = "/entities/{entity_id}")
    @PreAuthorize("@entity_pms.check(#entity_id,'DELETE')")
    public ResponseEntity<Boolean> remove(@PathVariable("entity_id") String entity_id) {
        boolean b = entityservice.remove( entity_id);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/entities/checkkey")
    @PreAuthorize("@entity_pms.check('')")
    public ResponseEntity<Boolean> checkKey(@RequestBody Entity entity) {
        boolean b = entityservice.checkKey(entity);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/entities/{entity_id}")
    @PreAuthorize("@entity_pms.check(#entity_id,'UPDATE')")
    public ResponseEntity<Entity> update(@PathVariable("entity_id") String entity_id, @RequestBody Entity entity) {
        Entity entity2 = entityservice.update(entity_id, entity);
        return ResponseEntity.status(HttpStatus.OK).body(entity2);
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/api/entities/{entity_id}")
    @PreAuthorize("@entity_pms.check(#entity_id,'UPDATE')")
    public ResponseEntity<Entity> api_update(@PathVariable("entity_id") String entity_id, @RequestBody Entity entity) {
        Entity entity2 = entityservice.update(entity_id, entity);
        return ResponseEntity.status(HttpStatus.OK).body(entity2);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/entities/getdraft")
    @PreAuthorize("@entity_pms.check('CREATE')")
    public ResponseEntity<Entity> getDraft() {
        //Entity entity = entityservice.getDraft( entity_id);
        return ResponseEntity.status(HttpStatus.OK).body(new Entity());
    }

    @RequestMapping(method= RequestMethod.GET , value="/entities/fetchdefault")
    @PreAuthorize("@entity_pms.check('READ')")
	public ResponseEntity<List<Entity>> fetchDefault(EntitySearchContext searchContext,Pageable pageable) {
        
        Page<Entity> page = entityservice.fetchDefault(searchContext);
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(pageable.getPageNumber()))
        		.header("x-per-page", String.valueOf(pageable.getPageSize()))
        		.header("x-total", String.valueOf(page.getTotalElements()))
        		.body(page.getContent());
    }


}
