package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import com.alibaba.fastjson.JSONObject;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service.PSDEWFService;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSDEWF;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;

@RestController
@RequestMapping(value = "")
public class PSDEWFController {
	@Autowired
    PSDEWFService psdewfservice;


	@RequestMapping(method = RequestMethod.GET, value = "/psdewfs/getdraft")
    @PreAuthorize("@psdewf_pms.check('CREATE')")
    public ResponseEntity<PSDEWF> getDraft() {
        //PSDEWF psdewf = psdewfservice.getDraft( psdewf_id);
        return ResponseEntity.status(HttpStatus.OK).body(new PSDEWF());
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.check(#psdewf_id,'UPDATE')")
    public ResponseEntity<PSDEWF> update(@PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.update(psdewf_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/api/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.check(#psdewf_id,'UPDATE')")
    public ResponseEntity<PSDEWF> api_update(@PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.update(psdewf_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psdewfs/checkkey")
    @PreAuthorize("@psdewf_pms.check('')")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSDEWF psdewf) {
        boolean b = psdewfservice.checkKey(psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.check(#psdewf_id,'READ')")
    public ResponseEntity<PSDEWF> get(@PathVariable("psdewf_id") String psdewf_id) {
        PSDEWF psdewf = psdewfservice.get( psdewf_id);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psdewfs")
    @PreAuthorize("@psdewf_pms.check('CREATE')")
    public ResponseEntity<PSDEWF> create(@RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.create(psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

	@RequestMapping(method = RequestMethod.DELETE, value = "/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.check(#psdewf_id,'DELETE')")
    public ResponseEntity<Boolean> remove(@PathVariable("psdewf_id") String psdewf_id) {
        boolean b = psdewfservice.remove( psdewf_id);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psdewfs/{psdewf_id}/save")
    @PreAuthorize("@psdewf_pms.check(#psdewf_id,'')")
    public ResponseEntity<PSDEWF> save(@PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.save(psdewf_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

    @RequestMapping(method= RequestMethod.GET , value="/psdewfs/fetchdefault")
    @PreAuthorize("@psdewf_pms.check('READ')")
	public ResponseEntity<List<PSDEWF>> fetchDefault(PSDEWFSearchContext searchContext,Pageable pageable) {
        
        Page<PSDEWF> page = psdewfservice.fetchDefault(searchContext);
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(pageable.getPageNumber()))
        		.header("x-per-page", String.valueOf(pageable.getPageSize()))
        		.header("x-total", String.valueOf(page.getTotalElements()))
        		.body(page.getContent());
    }


	@RequestMapping(method = RequestMethod.GET, value = "/psworkflows/{psworkflow_id}/psdewfs/getdraft")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,'CREATE')")
    public ResponseEntity<PSDEWF> getDraftByPSWorkflow() {
        //PSDEWF psdewf = psdewfservice.getDraftByPSWorkflow(psworkflow_id,  psdewf_id);
        return ResponseEntity.status(HttpStatus.OK).body(new PSDEWF());
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,#psdewf_id,'UPDATE')")
    public ResponseEntity<PSDEWF> updateByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.updateByPSWorkflow(psworkflow_id, psdewf_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

    @RequestMapping(method = RequestMethod.PUT, value = "/api/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,#psdewf_id,'UPDATE')")
    public ResponseEntity<PSDEWF> api_updateByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.updateByPSWorkflow(psworkflow_id, psdewf_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psworkflows/{psworkflow_id}/psdewfs/checkkey")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,'')")
    public ResponseEntity<Boolean> checkKeyByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSDEWF psdewf) {
        boolean b = psdewfservice.checkKeyByPSWorkflow(psworkflow_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,#psdewf_id,'READ')")
    public ResponseEntity<PSDEWF> getByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id) {
        PSDEWF psdewf = psdewfservice.getByPSWorkflow(psworkflow_id,  psdewf_id);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psworkflows/{psworkflow_id}/psdewfs")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,'CREATE')")
    public ResponseEntity<PSDEWF> createByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.createByPSWorkflow(psworkflow_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

	@RequestMapping(method = RequestMethod.DELETE, value = "/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,#psdewf_id,'DELETE')")
    public ResponseEntity<Boolean> removeByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id) {
        boolean b = psdewfservice.removeByPSWorkflow(psworkflow_id,  psdewf_id);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}/save")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,#psdewf_id,'')")
    public ResponseEntity<PSDEWF> saveByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWF psdewf) {
        PSDEWF psdewf2 = psdewfservice.saveByPSWorkflow(psworkflow_id, psdewf_id, psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewf2);
    }

    @RequestMapping(method= RequestMethod.GET , value="/psworkflows/{psworkflow_id}/psdewfs/fetchdefault")
    @PreAuthorize("@psdewf_pms.checkByPSWorkflow(#psworkflow_id,'READ')")
	public ResponseEntity<List<PSDEWF>> fetchDefaultByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id,PSDEWFSearchContext searchContext,Pageable pageable) {
        searchContext.setN_psworkflowid_eq(psworkflow_id);
        Page<PSDEWF> page = psdewfservice.fetchDefaultByPSWorkflow(psworkflow_id , searchContext);
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(pageable.getPageNumber()))
        		.header("x-per-page", String.valueOf(pageable.getPageSize()))
        		.header("x-total", String.valueOf(page.getTotalElements()))
        		.body(page.getContent());
    }


}
