package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import com.alibaba.fastjson.JSONObject;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service.WFInstanceService;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFInstance;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;

@RestController
@RequestMapping(value = "")
public class WFInstanceController {
	@Autowired
    WFInstanceService wfinstanceservice;


	@RequestMapping(method = RequestMethod.GET, value = "/wfinstances/{wfinstance_id}")
    @PreAuthorize("@wfinstance_pms.check(#wfinstance_id,'READ')")
    public ResponseEntity<WFInstance> get(@PathVariable("wfinstance_id") String wfinstance_id) {
        WFInstance wfinstance = wfinstanceservice.get( wfinstance_id);
        return ResponseEntity.status(HttpStatus.OK).body(wfinstance);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/wfinstances/checkkey")
    @PreAuthorize("@wfinstance_pms.check('')")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFInstance wfinstance) {
        boolean b = wfinstanceservice.checkKey(wfinstance);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.DELETE, value = "/wfinstances/{wfinstance_id}")
    @PreAuthorize("@wfinstance_pms.check(#wfinstance_id,'DELETE')")
    public ResponseEntity<Boolean> remove(@PathVariable("wfinstance_id") String wfinstance_id) {
        boolean b = wfinstanceservice.remove( wfinstance_id);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/wfinstances")
    @PreAuthorize("@wfinstance_pms.check('CREATE')")
    public ResponseEntity<WFInstance> create(@RequestBody WFInstance wfinstance) {
        WFInstance wfinstance2 = wfinstanceservice.create(wfinstance);
        return ResponseEntity.status(HttpStatus.OK).body(wfinstance2);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/wfinstances/getdraft")
    @PreAuthorize("@wfinstance_pms.check('CREATE')")
    public ResponseEntity<WFInstance> getDraft() {
        //WFInstance wfinstance = wfinstanceservice.getDraft( wfinstance_id);
        return ResponseEntity.status(HttpStatus.OK).body(new WFInstance());
    }

	@RequestMapping(method = RequestMethod.POST, value = "/wfinstances/{wfinstance_id}/save")
    @PreAuthorize("@wfinstance_pms.check(#wfinstance_id,'')")
    public ResponseEntity<WFInstance> save(@PathVariable("wfinstance_id") String wfinstance_id, @RequestBody WFInstance wfinstance) {
        WFInstance wfinstance2 = wfinstanceservice.save(wfinstance_id, wfinstance);
        return ResponseEntity.status(HttpStatus.OK).body(wfinstance2);
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/wfinstances/{wfinstance_id}")
    @PreAuthorize("@wfinstance_pms.check(#wfinstance_id,'UPDATE')")
    public ResponseEntity<WFInstance> update(@PathVariable("wfinstance_id") String wfinstance_id, @RequestBody WFInstance wfinstance) {
        WFInstance wfinstance2 = wfinstanceservice.update(wfinstance_id, wfinstance);
        return ResponseEntity.status(HttpStatus.OK).body(wfinstance2);
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/api/wfinstances/{wfinstance_id}")
    @PreAuthorize("@wfinstance_pms.check(#wfinstance_id,'UPDATE')")
    public ResponseEntity<WFInstance> api_update(@PathVariable("wfinstance_id") String wfinstance_id, @RequestBody WFInstance wfinstance) {
        WFInstance wfinstance2 = wfinstanceservice.update(wfinstance_id, wfinstance);
        return ResponseEntity.status(HttpStatus.OK).body(wfinstance2);
    }

    @RequestMapping(method= RequestMethod.GET , value="/wfinstances/fetchdefault")
    @PreAuthorize("@wfinstance_pms.check('READ')")
	public ResponseEntity<List<WFInstance>> fetchDefault(WFInstanceSearchContext searchContext,Pageable pageable) {
        
        Page<WFInstance> page = wfinstanceservice.fetchDefault(searchContext);
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(pageable.getPageNumber()))
        		.header("x-per-page", String.valueOf(pageable.getPageSize()))
        		.header("x-total", String.valueOf(page.getTotalElements()))
        		.body(page.getContent());
    }


}
