
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.OrgDeptWFVer;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.OrgDeptWFVerFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class OrgDeptWFVerService {

    OrgDeptWFVerFeignClient client;

    @Autowired
    public OrgDeptWFVerService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(OrgDeptWFVerFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(OrgDeptWFVerFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public OrgDeptWFVer getDraft(String orgdeptwfver_id, OrgDeptWFVer orgdeptwfver) {
        return client.getDraft(orgdeptwfver_id, orgdeptwfver);
    }

    public OrgDeptWFVer save(String orgdeptwfver_id, OrgDeptWFVer orgdeptwfver) {
        return client.save(orgdeptwfver_id, orgdeptwfver);
    }

    public boolean remove( String orgdeptwfver_id) {
        return client.remove( orgdeptwfver_id);
    }

	public OrgDeptWFVer create(OrgDeptWFVer orgdeptwfver) {
        return client.create(orgdeptwfver);
    }

    public OrgDeptWFVer update(String orgdeptwfver_id, OrgDeptWFVer orgdeptwfver) {
        return client.update(orgdeptwfver_id, orgdeptwfver);
    }

    public boolean checkKey(OrgDeptWFVer orgdeptwfver) {
        return client.checkKey(orgdeptwfver);
    }

    public OrgDeptWFVer get( String orgdeptwfver_id) {
        return client.get( orgdeptwfver_id);
    }

	public Page<OrgDeptWFVer> fetchDefault(OrgDeptWFVerSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

	public Page<OrgDeptWFVer> fetchCurOrgDept(OrgDeptWFVerSearchContext searchContext) {
        return client.fetchCurOrgDept(searchContext);
    }

}
