
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSDEWF;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.PSDEWFFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSDEWFService {

    PSDEWFFeignClient client;

    @Autowired
    public PSDEWFService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSDEWFFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSDEWFFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public PSDEWF getDraft(String psdewf_id, PSDEWF psdewf) {
        return client.getDraft(psdewf_id, psdewf);
    }

    public PSDEWF update(String psdewf_id, PSDEWF psdewf) {
        return client.update(psdewf_id, psdewf);
    }

    public boolean checkKey(PSDEWF psdewf) {
        return client.checkKey(psdewf);
    }

    public PSDEWF get( String psdewf_id) {
        return client.get( psdewf_id);
    }

	public PSDEWF create(PSDEWF psdewf) {
        return client.create(psdewf);
    }

    public boolean remove( String psdewf_id) {
        return client.remove( psdewf_id);
    }

    public PSDEWF save(String psdewf_id, PSDEWF psdewf) {
        return client.save(psdewf_id, psdewf);
    }

	public Page<PSDEWF> fetchDefault(PSDEWFSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }


    public PSDEWF getDraftByPSWorkflow(String psworkflow_id, String psdewf_id, PSDEWF psdewf) {
        return client.getDraftByPSWorkflow(psworkflow_id, psdewf_id, psdewf);
    }

    public PSDEWF updateByPSWorkflow(String psworkflow_id, String psdewf_id, PSDEWF psdewf) {
        return client.updateByPSWorkflow(psworkflow_id, psdewf_id, psdewf);
    }

    public boolean checkKeyByPSWorkflow(String psworkflow_id, PSDEWF psdewf) {
        return client.checkKeyByPSWorkflow(psworkflow_id, psdewf);
    }

    public PSDEWF getByPSWorkflow(String psworkflow_id,  String psdewf_id) {
        return client.getByPSWorkflow(psworkflow_id,  psdewf_id);
    }

	public PSDEWF createByPSWorkflow(String psworkflow_id, PSDEWF psdewf) {
        return client.createByPSWorkflow(psworkflow_id, psdewf);
    }

    public boolean removeByPSWorkflow(String psworkflow_id,  String psdewf_id) {
        return client.removeByPSWorkflow(psworkflow_id,  psdewf_id);
    }

    public PSDEWF saveByPSWorkflow(String psworkflow_id, String psdewf_id, PSDEWF psdewf) {
        return client.saveByPSWorkflow(psworkflow_id, psdewf_id, psdewf);
    }

	public Page<PSDEWF> fetchDefaultByPSWorkflow(String psworkflow_id , PSDEWFSearchContext searchContext) {
        return client.fetchDefaultByPSWorkflow(psworkflow_id , searchContext);
    }

}
