
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSDataEntity;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.PSDataEntityFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSDataEntityService {

    PSDataEntityFeignClient client;

    @Autowired
    public PSDataEntityService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSDataEntityFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSDataEntityFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public PSDataEntity getDraft(String psdataentity_id, PSDataEntity psdataentity) {
        return client.getDraft(psdataentity_id, psdataentity);
    }

    public PSDataEntity update(String psdataentity_id, PSDataEntity psdataentity) {
        return client.update(psdataentity_id, psdataentity);
    }

    public boolean remove( String psdataentity_id) {
        return client.remove( psdataentity_id);
    }

	public PSDataEntity create(PSDataEntity psdataentity) {
        return client.create(psdataentity);
    }

    public PSDataEntity save(String psdataentity_id, PSDataEntity psdataentity) {
        return client.save(psdataentity_id, psdataentity);
    }

    public PSDataEntity get( String psdataentity_id) {
        return client.get( psdataentity_id);
    }

    public boolean checkKey(PSDataEntity psdataentity) {
        return client.checkKey(psdataentity);
    }

	public Page<PSDataEntity> fetchDefault(PSDataEntitySearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
