
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSSysWFCat;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.PSSysWFCatFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSSysWFCatService {

    PSSysWFCatFeignClient client;

    @Autowired
    public PSSysWFCatService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSSysWFCatFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSSysWFCatFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public PSSysWFCat get( String pssyswfcat_id) {
        return client.get( pssyswfcat_id);
    }

    public boolean checkKey(PSSysWFCat pssyswfcat) {
        return client.checkKey(pssyswfcat);
    }

    public PSSysWFCat update(String pssyswfcat_id, PSSysWFCat pssyswfcat) {
        return client.update(pssyswfcat_id, pssyswfcat);
    }

    public PSSysWFCat save(String pssyswfcat_id, PSSysWFCat pssyswfcat) {
        return client.save(pssyswfcat_id, pssyswfcat);
    }

	public PSSysWFCat create(PSSysWFCat pssyswfcat) {
        return client.create(pssyswfcat);
    }

    public PSSysWFCat getDraft(String pssyswfcat_id, PSSysWFCat pssyswfcat) {
        return client.getDraft(pssyswfcat_id, pssyswfcat);
    }

    public boolean remove( String pssyswfcat_id) {
        return client.remove( pssyswfcat_id);
    }

	public Page<PSSysWFCat> fetchDefault(PSSysWFCatSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
