
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSWFProcRole;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.PSWFProcRoleFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSWFProcRoleService {

    PSWFProcRoleFeignClient client;

    @Autowired
    public PSWFProcRoleService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFProcRoleFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFProcRoleFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

	public PSWFProcRole create(PSWFProcRole pswfprocrole) {
        return client.create(pswfprocrole);
    }

    public PSWFProcRole getDraft(String pswfprocrole_id, PSWFProcRole pswfprocrole) {
        return client.getDraft(pswfprocrole_id, pswfprocrole);
    }

    public boolean remove( String pswfprocrole_id) {
        return client.remove( pswfprocrole_id);
    }

    public boolean checkKey(PSWFProcRole pswfprocrole) {
        return client.checkKey(pswfprocrole);
    }

    public PSWFProcRole get( String pswfprocrole_id) {
        return client.get( pswfprocrole_id);
    }

    public PSWFProcRole save(String pswfprocrole_id, PSWFProcRole pswfprocrole) {
        return client.save(pswfprocrole_id, pswfprocrole);
    }

    public PSWFProcRole update(String pswfprocrole_id, PSWFProcRole pswfprocrole) {
        return client.update(pswfprocrole_id, pswfprocrole);
    }

	public Page<PSWFProcRole> fetchDefault(PSWFProcRoleSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
