
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSWFProcess;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.PSWFProcessFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSWFProcessService {

    PSWFProcessFeignClient client;

    @Autowired
    public PSWFProcessService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFProcessFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFProcessFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(PSWFProcess pswfprocess) {
        return client.checkKey(pswfprocess);
    }

    public PSWFProcess update(String pswfprocess_id, PSWFProcess pswfprocess) {
        return client.update(pswfprocess_id, pswfprocess);
    }

    public PSWFProcess save(String pswfprocess_id, PSWFProcess pswfprocess) {
        return client.save(pswfprocess_id, pswfprocess);
    }

    public boolean remove( String pswfprocess_id) {
        return client.remove( pswfprocess_id);
    }

    public PSWFProcess getDraft(String pswfprocess_id, PSWFProcess pswfprocess) {
        return client.getDraft(pswfprocess_id, pswfprocess);
    }

    public PSWFProcess get( String pswfprocess_id) {
        return client.get( pswfprocess_id);
    }

	public PSWFProcess create(PSWFProcess pswfprocess) {
        return client.create(pswfprocess);
    }

	public Page<PSWFProcess> fetchDefault(PSWFProcessSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
