
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.PSWorkflow;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.PSWorkflowFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSWorkflowService {

    PSWorkflowFeignClient client;

    @Autowired
    public PSWorkflowService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWorkflowFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWorkflowFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public PSWorkflow save(String psworkflow_id, PSWorkflow psworkflow) {
        return client.save(psworkflow_id, psworkflow);
    }

    public boolean remove( String psworkflow_id) {
        return client.remove( psworkflow_id);
    }

    public PSWorkflow update(String psworkflow_id, PSWorkflow psworkflow) {
        return client.update(psworkflow_id, psworkflow);
    }

    public boolean checkKey(PSWorkflow psworkflow) {
        return client.checkKey(psworkflow);
    }

	public PSWorkflow create(PSWorkflow psworkflow) {
        return client.create(psworkflow);
    }

    public PSWorkflow getDraft(String psworkflow_id, PSWorkflow psworkflow) {
        return client.getDraft(psworkflow_id, psworkflow);
    }

    public PSWorkflow get( String psworkflow_id) {
        return client.get( psworkflow_id);
    }

	public Page<PSWorkflow> fetchCurOrg(PSWorkflowSearchContext searchContext) {
        return client.fetchCurOrg(searchContext);
    }

	public Page<PSWorkflow> fetchCurOrgDept(PSWorkflowSearchContext searchContext) {
        return client.fetchCurOrgDept(searchContext);
    }

	public Page<PSWorkflow> fetchDefault(PSWorkflowSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
