
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFApp;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.WFAppFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFAppService {

    WFAppFeignClient client;

    @Autowired
    public WFAppService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFAppFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFAppFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(WFApp wfapp) {
        return client.checkKey(wfapp);
    }

    public WFApp getDraft(String wfapp_id, WFApp wfapp) {
        return client.getDraft(wfapp_id, wfapp);
    }

    public WFApp update(String wfapp_id, WFApp wfapp) {
        return client.update(wfapp_id, wfapp);
    }

    public WFApp save(String wfapp_id, WFApp wfapp) {
        return client.save(wfapp_id, wfapp);
    }

    public WFApp get( String wfapp_id) {
        return client.get( wfapp_id);
    }

    public boolean remove( String wfapp_id) {
        return client.remove( wfapp_id);
    }

	public WFApp create(WFApp wfapp) {
        return client.create(wfapp);
    }

	public Page<WFApp> fetchDefault(WFAppSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
