
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFInstance;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.WFInstanceFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFInstanceService {

    WFInstanceFeignClient client;

    @Autowired
    public WFInstanceService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFInstanceFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFInstanceFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public WFInstance get( String wfinstance_id) {
        return client.get( wfinstance_id);
    }

    public boolean checkKey(WFInstance wfinstance) {
        return client.checkKey(wfinstance);
    }

    public boolean remove( String wfinstance_id) {
        return client.remove( wfinstance_id);
    }

	public WFInstance create(WFInstance wfinstance) {
        return client.create(wfinstance);
    }

    public WFInstance getDraft(String wfinstance_id, WFInstance wfinstance) {
        return client.getDraft(wfinstance_id, wfinstance);
    }

    public WFInstance save(String wfinstance_id, WFInstance wfinstance) {
        return client.save(wfinstance_id, wfinstance);
    }

    public WFInstance update(String wfinstance_id, WFInstance wfinstance) {
        return client.update(wfinstance_id, wfinstance);
    }

	public Page<WFInstance> fetchDefault(WFInstanceSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
