
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFMode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.WFModeFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFModeService {

    WFModeFeignClient client;

    @Autowired
    public WFModeService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFModeFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFModeFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(WFMode wfmode) {
        return client.checkKey(wfmode);
    }

    public boolean remove( String wfmode_id) {
        return client.remove( wfmode_id);
    }

    public WFMode get( String wfmode_id) {
        return client.get( wfmode_id);
    }

    public WFMode update(String wfmode_id, WFMode wfmode) {
        return client.update(wfmode_id, wfmode);
    }

    public WFMode getDraft(String wfmode_id, WFMode wfmode) {
        return client.getDraft(wfmode_id, wfmode);
    }

    public WFMode save(String wfmode_id, WFMode wfmode) {
        return client.save(wfmode_id, wfmode);
    }

	public WFMode create(WFMode wfmode) {
        return client.create(wfmode);
    }

	public Page<WFMode> fetchDefault(WFModeSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
