
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFRole;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.WFRoleFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFRoleService {

    WFRoleFeignClient client;

    @Autowired
    public WFRoleService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFRoleFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFRoleFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public WFRole getDraft(String wfrole_id, WFRole wfrole) {
        return client.getDraft(wfrole_id, wfrole);
    }

    public WFRole get( String wfrole_id) {
        return client.get( wfrole_id);
    }

	public WFRole create(WFRole wfrole) {
        return client.create(wfrole);
    }

    public boolean remove( String wfrole_id) {
        return client.remove( wfrole_id);
    }

    public WFRole update(String wfrole_id, WFRole wfrole) {
        return client.update(wfrole_id, wfrole);
    }

    public boolean checkKey(WFRole wfrole) {
        return client.checkKey(wfrole);
    }

    public WFRole save(String wfrole_id, WFRole wfrole) {
        return client.save(wfrole_id, wfrole);
    }

	public Page<WFRole> fetchDefault(WFRoleSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
