
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFStepActor;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.WFStepActorFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFStepActorService {

    WFStepActorFeignClient client;

    @Autowired
    public WFStepActorService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFStepActorFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFStepActorFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(WFStepActor wfstepactor) {
        return client.checkKey(wfstepactor);
    }

    public WFStepActor get( String wfstepactor_id) {
        return client.get( wfstepactor_id);
    }

	public WFStepActor create(WFStepActor wfstepactor) {
        return client.create(wfstepactor);
    }

    public boolean remove( String wfstepactor_id) {
        return client.remove( wfstepactor_id);
    }

    public WFStepActor save(String wfstepactor_id, WFStepActor wfstepactor) {
        return client.save(wfstepactor_id, wfstepactor);
    }

    public WFStepActor update(String wfstepactor_id, WFStepActor wfstepactor) {
        return client.update(wfstepactor_id, wfstepactor);
    }

    public WFStepActor getDraft(String wfstepactor_id, WFStepActor wfstepactor) {
        return client.getDraft(wfstepactor_id, wfstepactor);
    }

	public Page<WFStepActor> fetchDefault(WFStepActorSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
