
package cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.domain.WFStepData;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.admin.r7rt_wf.feign.WFStepDataFeignClient;
import cn.ibizlab.r7.runtime.wf.admin.AdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFStepDataService {

    WFStepDataFeignClient client;

    @Autowired
    public WFStepDataService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFStepDataFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFStepDataFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

	public WFStepData create(WFStepData wfstepdata) {
        return client.create(wfstepdata);
    }

    public WFStepData get( String wfstepdata_id) {
        return client.get( wfstepdata_id);
    }

    public boolean checkKey(WFStepData wfstepdata) {
        return client.checkKey(wfstepdata);
    }

    public WFStepData update(String wfstepdata_id, WFStepData wfstepdata) {
        return client.update(wfstepdata_id, wfstepdata);
    }

    public boolean remove( String wfstepdata_id) {
        return client.remove( wfstepdata_id);
    }

    public WFStepData getDraft(String wfstepdata_id, WFStepData wfstepdata) {
        return client.getDraft(wfstepdata_id, wfstepdata);
    }

    public WFStepData save(String wfstepdata_id, WFStepData wfstepdata) {
        return client.save(wfstepdata_id, wfstepdata);
    }

	public Page<WFStepData> fetchByBswfdata(WFStepDataSearchContext searchContext) {
        return client.fetchByBswfdata(searchContext);
    }

	public Page<WFStepData> fetchByBsdata(WFStepDataSearchContext searchContext) {
        return client.fetchByBsdata(searchContext);
    }

	public Page<WFStepData> fetchDefault(WFStepDataSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
