
package cn.ibizlab.r7.runtime.wf.portal.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.portal.r7rt_wf.domain.WFWorklist;
import cn.ibizlab.r7.runtime.wf.portal.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.portal.r7rt_wf.feign.WFWorklistFeignClient;
import cn.ibizlab.r7.runtime.wf.portal.PortalApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class WFWorklistService {

    WFWorklistFeignClient client;

    @Autowired
    public WFWorklistService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFWorklistFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(WFWorklistFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(WFWorklist wfworklist) {
        return client.checkKey(wfworklist);
    }

    public WFWorklist getDraft(String wfworklist_id, WFWorklist wfworklist) {
        return client.getDraft(wfworklist_id, wfworklist);
    }

    public WFWorklist update(String wfworklist_id, WFWorklist wfworklist) {
        return client.update(wfworklist_id, wfworklist);
    }

    public boolean remove( String wfworklist_id) {
        return client.remove( wfworklist_id);
    }

    public WFWorklist get( String wfworklist_id) {
        return client.get( wfworklist_id);
    }

    public WFWorklist save(String wfworklist_id, WFWorklist wfworklist) {
        return client.save(wfworklist_id, wfworklist);
    }

	public WFWorklist create(WFWorklist wfworklist) {
        return client.create(wfworklist);
    }

	public Page<WFWorklist> fetchDefault(WFWorklistSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

	public Page<WFWorklist> fetchDoneTask(WFWorklistSearchContext searchContext) {
        return client.fetchDoneTask(searchContext);
    }

	public Page<WFWorklist> fetchTodoTask(WFWorklistSearchContext searchContext) {
        return client.fetchTodoTask(searchContext);
    }

}
