package cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import com.alibaba.fastjson.JSONObject;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.service.PSWFVersionService;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.domain.PSWFVersion;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.filter.*;

@RestController
@RequestMapping(value = "")
public class PSWFVersionController {
	@Autowired
    PSWFVersionService pswfversionservice;


	@RequestMapping(method = RequestMethod.POST, value = "/pswfversions/checkkey")
    @PreAuthorize("@pswfversion_pms.check('')")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFVersion pswfversion) {
        boolean b = pswfversionservice.checkKey(pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/pswfversions/getdraft")
    @PreAuthorize("@pswfversion_pms.check('CREATE')")
    public ResponseEntity<PSWFVersion> getDraft() {
        //PSWFVersion pswfversion = pswfversionservice.getDraft( pswfversion_id);
        return ResponseEntity.status(HttpStatus.OK).body(new PSWFVersion());
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.check(#pswfversion_id,'UPDATE')")
    public ResponseEntity<PSWFVersion> update(@PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.update(pswfversion_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/api/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.check(#pswfversion_id,'UPDATE')")
    public ResponseEntity<PSWFVersion> api_update(@PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.update(pswfversion_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.check(#pswfversion_id,'READ')")
    public ResponseEntity<PSWFVersion> get(@PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersion pswfversion = pswfversionservice.get( pswfversion_id);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/pswfversions")
    @PreAuthorize("@pswfversion_pms.check('CREATE')")
    public ResponseEntity<PSWFVersion> create(@RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.create(pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

	@RequestMapping(method = RequestMethod.DELETE, value = "/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.check(#pswfversion_id,'DELETE')")
    public ResponseEntity<Boolean> remove(@PathVariable("pswfversion_id") String pswfversion_id) {
        boolean b = pswfversionservice.remove( pswfversion_id);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/pswfversions/{pswfversion_id}/save")
    @PreAuthorize("@pswfversion_pms.check(#pswfversion_id,'')")
    public ResponseEntity<PSWFVersion> save(@PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.save(pswfversion_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

    @RequestMapping(method= RequestMethod.GET , value="/pswfversions/fetchdefault")
    @PreAuthorize("@pswfversion_pms.check('READ')")
	public ResponseEntity<List<PSWFVersion>> fetchDefault(PSWFVersionSearchContext searchContext,Pageable pageable) {
        
        Page<PSWFVersion> page = pswfversionservice.fetchDefault(searchContext);
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(pageable.getPageNumber()))
        		.header("x-per-page", String.valueOf(pageable.getPageSize()))
        		.header("x-total", String.valueOf(page.getTotalElements()))
        		.body(page.getContent());
    }


	@RequestMapping(method = RequestMethod.POST, value = "/psworkflows/{psworkflow_id}/pswfversions/checkkey")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,'')")
    public ResponseEntity<Boolean> checkKeyByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWFVersion pswfversion) {
        boolean b = pswfversionservice.checkKeyByPSWorkflow(psworkflow_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/psworkflows/{psworkflow_id}/pswfversions/getdraft")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,'CREATE')")
    public ResponseEntity<PSWFVersion> getDraftByPSWorkflow() {
        //PSWFVersion pswfversion = pswfversionservice.getDraftByPSWorkflow(psworkflow_id,  pswfversion_id);
        return ResponseEntity.status(HttpStatus.OK).body(new PSWFVersion());
    }

	@RequestMapping(method = RequestMethod.PUT, value = "/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,#pswfversion_id,'UPDATE')")
    public ResponseEntity<PSWFVersion> updateByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.updateByPSWorkflow(psworkflow_id, pswfversion_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

    @RequestMapping(method = RequestMethod.PUT, value = "/api/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,#pswfversion_id,'UPDATE')")
    public ResponseEntity<PSWFVersion> api_updateByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.updateByPSWorkflow(psworkflow_id, pswfversion_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

	@RequestMapping(method = RequestMethod.GET, value = "/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,#pswfversion_id,'READ')")
    public ResponseEntity<PSWFVersion> getByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersion pswfversion = pswfversionservice.getByPSWorkflow(psworkflow_id,  pswfversion_id);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psworkflows/{psworkflow_id}/pswfversions")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,'CREATE')")
    public ResponseEntity<PSWFVersion> createByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.createByPSWorkflow(psworkflow_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

	@RequestMapping(method = RequestMethod.DELETE, value = "/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,#pswfversion_id,'DELETE')")
    public ResponseEntity<Boolean> removeByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id) {
        boolean b = pswfversionservice.removeByPSWorkflow(psworkflow_id,  pswfversion_id);
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@RequestMapping(method = RequestMethod.POST, value = "/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}/save")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,#pswfversion_id,'')")
    public ResponseEntity<PSWFVersion> saveByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersion pswfversion) {
        PSWFVersion pswfversion2 = pswfversionservice.saveByPSWorkflow(psworkflow_id, pswfversion_id, pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversion2);
    }

    @RequestMapping(method= RequestMethod.GET , value="/psworkflows/{psworkflow_id}/pswfversions/fetchdefault")
    @PreAuthorize("@pswfversion_pms.checkByPSWorkflow(#psworkflow_id,'READ')")
	public ResponseEntity<List<PSWFVersion>> fetchDefaultByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id,PSWFVersionSearchContext searchContext,Pageable pageable) {
        searchContext.setN_psworkflowid_eq(psworkflow_id);
        Page<PSWFVersion> page = pswfversionservice.fetchDefaultByPSWorkflow(psworkflow_id , searchContext);
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(pageable.getPageNumber()))
        		.header("x-per-page", String.valueOf(pageable.getPageSize()))
        		.header("x-total", String.valueOf(page.getTotalElements()))
        		.body(page.getContent());
    }


}
