
package cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.domain.PSWFRoleDetail;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.feign.PSWFRoleDetailFeignClient;
import cn.ibizlab.r7.runtime.wf.wfadmin.WFAdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSWFRoleDetailService {

    PSWFRoleDetailFeignClient client;

    @Autowired
    public PSWFRoleDetailService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFRoleDetailFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFRoleDetailFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public PSWFRoleDetail save(String pswfroledetail_id, PSWFRoleDetail pswfroledetail) {
        return client.save(pswfroledetail_id, pswfroledetail);
    }

    public PSWFRoleDetail update(String pswfroledetail_id, PSWFRoleDetail pswfroledetail) {
        return client.update(pswfroledetail_id, pswfroledetail);
    }

    public PSWFRoleDetail get( String pswfroledetail_id) {
        return client.get( pswfroledetail_id);
    }

    public boolean checkKey(PSWFRoleDetail pswfroledetail) {
        return client.checkKey(pswfroledetail);
    }

	public PSWFRoleDetail create(PSWFRoleDetail pswfroledetail) {
        return client.create(pswfroledetail);
    }

    public PSWFRoleDetail getDraft(String pswfroledetail_id, PSWFRoleDetail pswfroledetail) {
        return client.getDraft(pswfroledetail_id, pswfroledetail);
    }

    public boolean remove( String pswfroledetail_id) {
        return client.remove( pswfroledetail_id);
    }

	public Page<PSWFRoleDetail> fetchDefault(PSWFRoleDetailSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }


    public PSWFRoleDetail saveByPSWFRole(String pswfrole_id, String pswfroledetail_id, PSWFRoleDetail pswfroledetail) {
        return client.saveByPSWFRole(pswfrole_id, pswfroledetail_id, pswfroledetail);
    }

    public PSWFRoleDetail updateByPSWFRole(String pswfrole_id, String pswfroledetail_id, PSWFRoleDetail pswfroledetail) {
        return client.updateByPSWFRole(pswfrole_id, pswfroledetail_id, pswfroledetail);
    }

    public PSWFRoleDetail getByPSWFRole(String pswfrole_id,  String pswfroledetail_id) {
        return client.getByPSWFRole(pswfrole_id,  pswfroledetail_id);
    }

    public boolean checkKeyByPSWFRole(String pswfrole_id, PSWFRoleDetail pswfroledetail) {
        return client.checkKeyByPSWFRole(pswfrole_id, pswfroledetail);
    }

	public PSWFRoleDetail createByPSWFRole(String pswfrole_id, PSWFRoleDetail pswfroledetail) {
        return client.createByPSWFRole(pswfrole_id, pswfroledetail);
    }

    public PSWFRoleDetail getDraftByPSWFRole(String pswfrole_id, String pswfroledetail_id, PSWFRoleDetail pswfroledetail) {
        return client.getDraftByPSWFRole(pswfrole_id, pswfroledetail_id, pswfroledetail);
    }

    public boolean removeByPSWFRole(String pswfrole_id,  String pswfroledetail_id) {
        return client.removeByPSWFRole(pswfrole_id,  pswfroledetail_id);
    }

	public Page<PSWFRoleDetail> fetchDefaultByPSWFRole(String pswfrole_id , PSWFRoleDetailSearchContext searchContext) {
        return client.fetchDefaultByPSWFRole(pswfrole_id , searchContext);
    }

}
