
package cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.domain.PSWFRole;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.feign.PSWFRoleFeignClient;
import cn.ibizlab.r7.runtime.wf.wfadmin.WFAdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSWFRoleService {

    PSWFRoleFeignClient client;

    @Autowired
    public PSWFRoleService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFRoleFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFRoleFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(PSWFRole pswfrole) {
        return client.checkKey(pswfrole);
    }

    public PSWFRole update(String pswfrole_id, PSWFRole pswfrole) {
        return client.update(pswfrole_id, pswfrole);
    }

    public PSWFRole get( String pswfrole_id) {
        return client.get( pswfrole_id);
    }

    public PSWFRole getDraft(String pswfrole_id, PSWFRole pswfrole) {
        return client.getDraft(pswfrole_id, pswfrole);
    }

    public boolean remove( String pswfrole_id) {
        return client.remove( pswfrole_id);
    }

	public PSWFRole create(PSWFRole pswfrole) {
        return client.create(pswfrole);
    }

    public PSWFRole save(String pswfrole_id, PSWFRole pswfrole) {
        return client.save(pswfrole_id, pswfrole);
    }

	public Page<PSWFRole> fetchCurOrg(PSWFRoleSearchContext searchContext) {
        return client.fetchCurOrg(searchContext);
    }

	public Page<PSWFRole> fetchCurOrgDept(PSWFRoleSearchContext searchContext) {
        return client.fetchCurOrgDept(searchContext);
    }

	public Page<PSWFRole> fetchDefault(PSWFRoleSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
