
package cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.wf.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.domain.PSWFVersion;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.filter.*;
import cn.ibizlab.r7.runtime.wf.wfadmin.r7rt_wf.feign.PSWFVersionFeignClient;
import cn.ibizlab.r7.runtime.wf.wfadmin.WFAdminApplication.WFApiClientProperties;
import cn.ibizlab.r7.runtime.wf.util.feign.FeignRequestInterceptor;

@Service
public class PSWFVersionService {

    PSWFVersionFeignClient client;

    @Autowired
    public PSWFVersionService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WFApiClientProperties wfapiClientProperties) {
        if (wfapiClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFVersionFeignClient.class,"http://" + wfapiClientProperties.getServiceId() + "/") ;
		} else if (wfapiClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(PSWFVersionFeignClient.class, "http://" + wfapiClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(PSWFVersion pswfversion) {
        return client.checkKey(pswfversion);
    }

    public PSWFVersion getDraft(String pswfversion_id, PSWFVersion pswfversion) {
        return client.getDraft(pswfversion_id, pswfversion);
    }

    public PSWFVersion update(String pswfversion_id, PSWFVersion pswfversion) {
        return client.update(pswfversion_id, pswfversion);
    }

    public PSWFVersion get( String pswfversion_id) {
        return client.get( pswfversion_id);
    }

	public PSWFVersion create(PSWFVersion pswfversion) {
        return client.create(pswfversion);
    }

    public boolean remove( String pswfversion_id) {
        return client.remove( pswfversion_id);
    }

    public PSWFVersion save(String pswfversion_id, PSWFVersion pswfversion) {
        return client.save(pswfversion_id, pswfversion);
    }

	public Page<PSWFVersion> fetchDefault(PSWFVersionSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }


    public boolean checkKeyByPSWorkflow(String psworkflow_id, PSWFVersion pswfversion) {
        return client.checkKeyByPSWorkflow(psworkflow_id, pswfversion);
    }

    public PSWFVersion getDraftByPSWorkflow(String psworkflow_id, String pswfversion_id, PSWFVersion pswfversion) {
        return client.getDraftByPSWorkflow(psworkflow_id, pswfversion_id, pswfversion);
    }

    public PSWFVersion updateByPSWorkflow(String psworkflow_id, String pswfversion_id, PSWFVersion pswfversion) {
        return client.updateByPSWorkflow(psworkflow_id, pswfversion_id, pswfversion);
    }

    public PSWFVersion getByPSWorkflow(String psworkflow_id,  String pswfversion_id) {
        return client.getByPSWorkflow(psworkflow_id,  pswfversion_id);
    }

	public PSWFVersion createByPSWorkflow(String psworkflow_id, PSWFVersion pswfversion) {
        return client.createByPSWorkflow(psworkflow_id, pswfversion);
    }

    public boolean removeByPSWorkflow(String psworkflow_id,  String pswfversion_id) {
        return client.removeByPSWorkflow(psworkflow_id,  pswfversion_id);
    }

    public PSWFVersion saveByPSWorkflow(String psworkflow_id, String pswfversion_id, PSWFVersion pswfversion) {
        return client.saveByPSWorkflow(psworkflow_id, pswfversion_id, pswfversion);
    }

	public Page<PSWFVersion> fetchDefaultByPSWorkflow(String psworkflow_id , PSWFVersionSearchContext searchContext) {
        return client.fetchDefaultByPSWorkflow(psworkflow_id , searchContext);
    }

}
